SystemOrganization addCategory: #Deli!
SystemOrganization addCategory: #'Deli-models'!
SystemOrganization addCategory: #'Deli-configuration'!
SystemOrganization addCategory: #'Deli-models-tests'!
SystemOrganization addCategory: #'Deli-frontend'!

SqsTestCase subclass: #DLDeliTestCase
	instanceVariableNames: 'semester lecture user membership group'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

DLDeliTestCase subclass: #DLDeadlineTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

!DLDeliTestCase methodsFor: 'as yet unclassified' stamp: 'sebh 5/28/2009 10:37'!
fixture
	"We assume that creation through the orm works."
	| userJack userJohn |
	semester := DLSemester new
		semesterName: 'Winter';
		year: 2009;
		save.
	
	lecture := DLLecture new
		lectureName: 'Softwaretechnik I';
		lectureDescription: 'An introduction to techniques in software development';
		semester: semester;
		save.
	
	user := DLUser new
		userName: 'john';
		save.
	
	userJack := DLUser createUserName: 'jack' email: 'jack@student.hpi.uni-potsdam.de'.
	userJohn := DLUser createFrom: {#userName->'john'. #email->'john@hpi.uni-potsdam.de'. #isAdmin->true}.
	
	
	membership := DLLectureMembership new
		user: user;
		lecture: lecture;
		role: #student;
		save.

	group := DLGroup new
		groupName: 'Roundup porns';
		groupDescription: 'Roundup in awesome';
		lecture: lecture;
		users: ( {user} as: OrderedCollection );
		save.! !

!DLDeliTestCase methodsFor: 'as yet unclassified' stamp: 'sebh 5/28/2009 09:50'!
setUp
	| session |
	super setUp.
	session := SqsConnectionManager getInstance sessionForClass: DLLecture.
	session resetDatabase.
	self fixture.
	"session beginTransaction."

! !

!DLDeliTestCase methodsFor: 'as yet unclassified' stamp: 'sebh 5/20/2009 19:35'!
tearDown
	| session |
	super tearDown.
	
	"""session := SqsConnectionManager getInstance sessionForClass: DLLecture.
	session rollbackTransaction."""
! !

DLDeliTestCase subclass: #DLGeneralTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

!DLGeneralTests methodsFor: 'as yet unclassified' stamp: 'sebh 5/28/2009 13:01'!
testCreate
	
	| aUser bUser |
	aUser := DLUser createFrom: {#userName->'dylan'. #email->'dylan@myhpi.com'. #isAdmin->'true'}.
	
	self assert: ((SqsSearch for: DLUser) detect: [:anUser | anUser userName = 'dylan'] ifNone: [nil]) notNil.
	
	bUser := DLUser getOrCreateFrom: {#userName->'dylan'}.
	
	self assert: aUser equals: bUser.! !

DLDeliTestCase subclass: #DLLectureMembershipTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

!DLLectureMembershipTest methodsFor: 'as yet unclassified' stamp: 'Marik 5/26/2009 17:55'!
testUniqueMemberships
	| aNotAllowedMembership |
	aNotAllowedMembership := DLLectureMembership withLecture: lecture user: user role: #teacher.
	self assert: [aNotAllowedMembership isNil] description: 'A second membership on the same person should not be created.'.
	
	membership destroy.
	membership := DLLectureMembership withLecture: lecture user: user role: #teacher.
	
	self assert: [ membership notNil] description: 'A membership can be created after the other membership was deleted.'.
! !

DLDeliTestCase subclass: #DLLectureTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

DLDeliTestCase subclass: #DLSemesterTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models-tests'!

Announcement subclass: #DLViewCompReplacement
	instanceVariableNames: 'component'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLViewCompReplacement class methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 17:57'!
forComponent: aComponent
	^ self new
		component: aComponent;
		yourself.! !

!DLViewCompReplacement methodsFor: 'accessing' stamp: 'sebh 6/3/2009 17:55'!
component

	^ component! !

!DLViewCompReplacement methodsFor: 'accessing' stamp: 'sebh 6/3/2009 17:55'!
component: anObject

	component := anObject.! !

WAFileLibrary subclass: #DLFileLibrary
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLFileLibrary methodsFor: 'as yet unclassified' stamp: 'cr 6/1/2009 01:16'!
selectorsToInclude

	^ Array with: 'styleCss'! !

!DLFileLibrary methodsFor: 'uploaded' stamp: 'cr 6/1/2009 01:25'!
styleCss
	^
'.menu {
	float: left;
	width: 250px;
	padding: 10px;
}

thead>td {
	font-weight: bold;
}
'! !

!DLFileLibrary methodsFor: 'as yet unclassified' stamp: 'cr 6/1/2009 01:14'!
updateRoot:	anHtmlRoot
	super updateRoot: anHtmlRoot.
	anHtmlRoot stylesheet url: DLFileLibrary / #styleCss.! !

WAComponent subclass: #DLComponent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLComponent methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 17:59'!
initialize
	super initialize.! !

!DLComponent methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 16:59'!
permissionCheck
	^ false.! !

!DLComponent methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 14:47'!
renderContent: html
	self subclassResponsibility! !

!DLComponent methodsFor: 'accessing' stamp: 'sebh 6/3/2009 18:01'!
renderContentOn: html
	html div with: [ html text: 'Logged in as ', self session user userName].
	self permissionCheck 
		ifTrue: [self renderContent: html.]
		ifFalse:[html div with: 'permission denied']
	! !

DLComponent subclass: #DLLectureDetailComp
	instanceVariableNames: 'lecture'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLLectureDetailComp class methodsFor: 'as yet unclassified' stamp: 'cr 6/3/2009 21:07'!
for: aLecture
	^self new
		lecture: aLecture;
		yourself.! !

!DLLectureDetailComp methodsFor: 'accessing' stamp: 'cr 6/3/2009 21:04'!
lecture

	^ lecture! !

!DLLectureDetailComp methodsFor: 'accessing' stamp: 'cr 6/3/2009 21:04'!
lecture: anObject

	lecture := anObject.! !

!DLLectureDetailComp methodsFor: 'as yet unclassified' stamp: 'cr 6/3/2009 21:00'!
permissionCheck
	^true! !

!DLLectureDetailComp methodsFor: 'as yet unclassified' stamp: 'cr 6/3/2009 21:15'!
renderContent: html
	self lecture description do: [:desc |
		html text: desc label.
		html text: ': '.
		html text: (desc toString: (desc accessor read: (self lecture))).
		html break.
		]! !

DLComponent subclass: #DLLectureFormComp
	instanceVariableNames: 'lecture lectureForm'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLLectureFormComp class methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 17:52'!
for: anObject
	^ self new
		lectureForm: (DLLectureUpdateTask for: anObject);
		yourself.! !

!DLLectureFormComp methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 17:53'!
children
	^ Array with: self lectureForm.! !

!DLLectureFormComp methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 17:51'!
initialize
	super initialize.
	self lectureForm: DLLectureUpdateTask new.! !

!DLLectureFormComp methodsFor: 'accessing' stamp: 'sebh 6/3/2009 17:47'!
lectureForm

	^ lectureForm! !

!DLLectureFormComp methodsFor: 'accessing' stamp: 'sebh 6/3/2009 17:47'!
lectureForm: anObject

	lectureForm := anObject.! !

!DLLectureFormComp methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 17:56'!
permissionCheck
	^ self session user isAdmin.! !

!DLLectureFormComp methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 17:47'!
renderContent: html
	html div with: self lectureForm.! !

DLComponent subclass: #DLLectureListComp
	instanceVariableNames: 'report'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLLectureListComp methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 17:45'!
children
	^ Array with: self report! !

!DLLectureListComp methodsFor: 'as yet unclassified' stamp: 'cr 6/3/2009 21:01'!
initialize
	super initialize.
	self report: (MAReport rows: (SqsSearch for: DLLecture) findAll
							 	  description: DLLecture new descriptionList).
	self report addColumn: 
		(MACommandColumn new 
			addCommand: [:lecture | self call: (DLLectureFormComp for: lecture)] 
			text:'Bearbeiten'; 
			yourself).
	self report addColumn:
		(MACommandColumn new
			addCommand: [:lecture | self call: (DLLectureDetailComp for: lecture)]
			text: 'Details';
			yourself).! !

!DLLectureListComp methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 17:31'!
permissionCheck
	^ self session isLoggedIn.! !

!DLLectureListComp methodsFor: 'accessing' stamp: 'sebh 6/3/2009 17:16'!
renderContent: html
	html div with: self report.! !

!DLLectureListComp methodsFor: 'accessing' stamp: 'sebh 6/3/2009 17:08'!
report

	^ report! !

!DLLectureListComp methodsFor: 'accessing' stamp: 'sebh 6/3/2009 17:08'!
report: anObject

	report := anObject.! !

DLComponent subclass: #DLPermissionDeniedComp
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLPermissionDeniedComp methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 17:02'!
permissionCheck
	"Always allow anyone to see permission denied"
	^ true! !

!DLPermissionDeniedComp methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 17:24'!
renderContent: html
	html heading: 'Permission denied';
		  paragraph: 'You have insufficient rights to open this page.'! !

WAComponent subclass: #DLLectureMembershipListComp
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLLectureMembershipListComp methodsFor: 'rendering' stamp: 'MG 5/27/2009 20:56'!
renderContentOn: html
	
	html text: 'Lehrveranstaltungen, die du besuchst:';
		  break.
	self renderLectureMemberships: html;
		  answer: true.! !

!DLLectureMembershipListComp methodsFor: 'rendering' stamp: 'MG 5/27/2009 20:08'!
renderLectureMemberships: html

	| lectureMemberships currentUser |
	
	currentUser := self session user.
	lectureMemberships := (SqsSearch for: DLLectureMembership) select:[:aLectureMembership | 
		aLectureMembership user = currentUser].
	lectureMemberships do:[:aLectureMembership |
		html text: aLectureMembership lecture lectureName;
			  break]! !

WAComponent subclass: #DLMenuComp
	instanceVariableNames: 'entries content'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

DLMenuComp subclass: #DLAdminMenuComp
	instanceVariableNames: 'lectureListComp formComponent'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLAdminMenuComp methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 17:31'!
addEntries
	self entries
		add: 'Lehrveranstaltungen' -> {
					 'Neue Lehrveranstaltung anlegen' -> 
							[self showComponent: DLLectureFormComp new].
					'Alle Lehrveranstaltungen' -> 
							[self showComponent: DLLectureListComp new].
					'Recursive root' -> 
							[].
			   };
		add: 'Andere Aktionen' -> { 'Ausloggen' -> [] }.
! !

!DLMenuComp methodsFor: 'as yet unclassified' stamp: 'sebh 5/27/2009 15:27'!
addEntries
	"If an inheriting method has defined this method, we use it to automagically insert entries"! !

!DLMenuComp methodsFor: 'as yet unclassified' stamp: 'sebh 5/26/2009 17:12'!
addEntry: aString withAction: aBlock
	
	^ self entries add: aString -> aBlock! !

!DLMenuComp methodsFor: 'accessing' stamp: 'sebh 5/26/2009 17:08'!
entries

	^ entries! !

!DLMenuComp methodsFor: 'accessing' stamp: 'sebh 5/26/2009 17:08'!
entries: anObject

	entries := anObject.! !

!DLMenuComp methodsFor: 'as yet unclassified' stamp: 'sebh 5/27/2009 15:26'!
initialize
	super initialize.
	self entries: OrderedCollection new.
	self addEntries.! !

!DLMenuComp methodsFor: 'as yet unclassified' stamp: 'sebh 5/27/2009 15:42'!
renderContentOn: html

	self entries
		do: [:entry | self renderEntry: entry on: html. ]
		separatedBy: [html break].! !

!DLMenuComp methodsFor: 'as yet unclassified' stamp: 'sebh 5/27/2009 15:50'!
renderEntry: anEntry on: html
	self renderEntry: anEntry on: html level: 2 ! !

!DLMenuComp methodsFor: 'as yet unclassified' stamp: 'sebh 5/28/2009 12:45'!
renderEntry: anEntry on: html level: aLevel
	anEntry value isCollection
	ifTrue: [ 
		html heading: anEntry key level: aLevel.
		anEntry value do: [:entry | self renderEntry: entry on: html level: aLevel+1] separatedBy: [html break].
	]
	ifFalse: [
		html anchor
			callback: anEntry value;
			with: anEntry key.
	].! !

!DLMenuComp methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 17:58'!
showComponent: aComponent
	self session announcer announce: ((self signal) forComponent: aComponent)! !

!DLMenuComp methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 17:55'!
signal
	^ DLViewCompReplacement! !

WAComponent subclass: #DLRootComponent
	instanceVariableNames: 'menuComp viewComp'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLRootComponent methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 12:00'!
children
	^ Array with: self viewComp with: self menuComp! !

!DLRootComponent methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 17:58'!
initialize
	super initialize.
	self menuComp: DLAdminMenuComp new.
	self session announcer on: DLViewCompReplacement do: [:announcement | self viewComp: announcement component ]! !

!DLRootComponent methodsFor: 'accessing' stamp: 'sebh 6/3/2009 12:10'!
menuComp

	^ menuComp! !

!DLRootComponent methodsFor: 'accessing' stamp: 'sebh 6/3/2009 12:10'!
menuComp: anObject

	menuComp := anObject.! !

!DLRootComponent methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 12:10'!
renderContentOn: html
	html div class:'menu'; with: self menuComp.
	html div class:'content'; with: self viewComp.! !

!DLRootComponent methodsFor: 'accessing' stamp: 'sebh 6/3/2009 12:10'!
viewComp

	^ viewComp! !

!DLRootComponent methodsFor: 'accessing' stamp: 'sebh 6/3/2009 12:10'!
viewComp: anObject

	viewComp := anObject.! !

WATask subclass: #DLLectureUpdateTask
	instanceVariableNames: 'lecture'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLLectureUpdateTask class methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 14:07'!
for: anObject
	^ self new
		lecture: anObject;
		yourself.! !

!DLLectureUpdateTask methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 18:04'!
go
	lecture := self call: ((self lecture asComponent) addValidatedForm).
	lecture ifNotNil: [
		lecture save.
		self session announcer announce: (DLViewCompReplacement forComponent: DLLectureListComp new)
		]! !

!DLLectureUpdateTask methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 14:10'!
initialize
	super initialize.
	self lecture: DLLecture new.! !

!DLLectureUpdateTask methodsFor: 'accessing' stamp: 'sebh 6/3/2009 14:09'!
lecture

	^ lecture! !

!DLLectureUpdateTask methodsFor: 'accessing' stamp: 'sebh 6/3/2009 14:09'!
lecture: anObject

	lecture := anObject.! !

WATask subclass: #DLRootTask
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLRootTask class methodsFor: 'testing' stamp: 'Marik 5/26/2009 13:30'!
canBeRoot

	^true! !

!DLRootTask methodsFor: 'processing' stamp: 'MG 5/27/2009 20:35'!
go

	self loginUser.! !

!DLRootTask methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 12:19'!
loginUser

	| loginAnswer |
	
	loginAnswer := self call: DLLoginUser new asComponent addValidatedForm.
	loginAnswer
		ifNotNil: [ | user |
			self resetOldSession.
			user := (loginAnswer validateLogin).
			user ifNotNil: [self session login: user]].
	self call: DLRootComponent  new.
	! !

!DLRootTask methodsFor: 'as yet unclassified' stamp: 'Marik 6/2/2009 16:21'!
resetOldSession

	(self session user notNil)
		ifTrue: [self session expire].! !

Object subclass: #DLLoginUser
	instanceVariableNames: 'userName password'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

DLLoginUser class
	instanceVariableNames: 'userName password'!

DLLoginUser class
	instanceVariableNames: 'userName password'!

!DLLoginUser class methodsFor: 'as yet unclassified' stamp: 'Marik 6/2/2009 16:52'!
descriptionPassword
	^ (MAPasswordDescription auto: 'password' label: 'Passwort' priority:20)
			beRequired;
			yourself.! !

!DLLoginUser class methodsFor: 'as yet unclassified' stamp: 'Marik 6/2/2009 15:26'!
descriptionUserName
	^ (MAStringDescription auto: 'userName' label: 'Name' priority:10)
			beRequired;
			yourself.! !

!DLLoginUser class methodsFor: 'accessing-generated' stamp: 'Marik 6/2/2009 15:28'!
password
	^ password! !

!DLLoginUser class methodsFor: 'accessing-generated' stamp: 'Marik 6/2/2009 15:49'!
password: anObject
	password := anObject! !

!DLLoginUser class methodsFor: 'accessing-generated' stamp: 'Marik 6/2/2009 15:27'!
userName
	^ userName! !

!DLLoginUser class methodsFor: 'accessing-generated' stamp: 'Marik 6/2/2009 15:49'!
userName: anObject
	userName := anObject! !

!DLLoginUser methodsFor: 'accessing' stamp: 'Marik 6/2/2009 16:42'!
acceptUser

	|user|
	user := DLUser getOrCreateUserName: self userName email: userName, '@student.hpi.uni-potsdam.de'.
	self 	clearUserData.
	^ user! !

!DLLoginUser methodsFor: 'accessing' stamp: 'Marik 6/2/2009 16:16'!
clearUserData

	self 	userName: nil;
			password: nil! !

!DLLoginUser methodsFor: 'accessing' stamp: 'Marik 6/2/2009 16:43'!
denyUser

	self 	clearUserData.
	^ nil! !

!DLLoginUser methodsFor: 'accessing-generated' stamp: 'sebh 5/27/2009 12:03'!
password
	^ password! !

!DLLoginUser methodsFor: 'accessing' stamp: 'Marik 6/2/2009 16:00'!
password: anObject

	password := anObject.! !

!DLLoginUser methodsFor: 'accessing-generated' stamp: 'sebh 5/27/2009 12:03'!
userName
	^ userName! !

!DLLoginUser methodsFor: 'accessing' stamp: 'Marik 6/2/2009 16:00'!
userName: anObject

	userName := anObject.! !

!DLLoginUser methodsFor: 'accessing' stamp: 'Marik 6/2/2009 16:37'!
validateLogin

	|loginChecker|
	
	"A test user so we don't need to have hpi nads2 present all the time"
	(self userName = 'john' and: [self password = 'john']) | (self userName = 'jack' and: [self password = 'jack'])
		ifTrue: [^self acceptUser].
	"A bad test user"
	self userName =  'christian'
		ifTrue: [^self denyUser].
	
	loginChecker := HPILoginChecker new.
	(loginChecker checkLogin: self userName password: self password)
		ifTrue:[^self acceptUser]
		ifFalse:[^self denyUser]! !

Object subclass: #DLModel
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

DLModel subclass: #DLDeadline
	instanceVariableNames: 'deadlineName deadlineDescription date'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLDeadline class methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 21:02'!
descriptionDate
	^ (MADateDescription auto: 'date' label: 'Datum' priority: 30)
			beRequired;
			yourself.
! !

!DLDeadline class methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 21:00'!
descriptionDeadlineDescription
	^ (MAMemoDescription new auto:'deadlineDescription'; label: 'Beschreibung'; priority: 20) 
		beRequired;
		yourself.! !

!DLDeadline class methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 21:01'!
descriptionLectureName
	^ (MAStringDescription auto: 'deadlineName' label: 'Titel' priority: 10)
			beRequired;
			yourself.
! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
date

	^ date! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
date: anObject

	date := anObject.! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 6/3/2009 20:57'!
deadlineDescription

	^ deadlineDescription! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 6/3/2009 20:57'!
deadlineDescription: anObject

	deadlineDescription := anObject.! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
deadlineName

	^ deadlineName! !

!DLDeadline methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:55'!
deadlineName: anObject

	deadlineName := anObject.! !

DLModel subclass: #DLLecture
	instanceVariableNames: 'lectureName lectureDescription semester teacher assistants groupSize'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

DLLecture class
	instanceVariableNames: 'semester teacherName lectureName lectureDescription assistentName groupSize'!

DLLecture class
	instanceVariableNames: 'semester teacherName lectureName lectureDescription assistentName groupSize'!

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'Marik 5/27/2009 15:42'!
createLectureName: aLectureName semester: aSemester description: aDescription
	^ self new
		lectureName: aLectureName;
		semester: aSemester;
		description: aDescription;
		save;
		yourself.! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 20:36'!
descriptionAssistants
	^ (MAMultipleOptionDescription auto: 'assistants' label: 'Assistenten' priority: 40)
		 	optionsAndLabels: (DLUser getKeyValueSelect: [:aUser | ]);
			yourself.
! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 16:01'!
descriptionGroupSize
	^ (MANumberDescription auto: 'groupSize' label: 'Gruppengre' priority: 60)
			yourself.
! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 16:01'!
descriptionLectureDescription
	^ (MAMemoDescription auto: 'lectureDescription' label: 'Beschreibung' priority: 20)
			yourself.
! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 16:01'!
descriptionLectureName
	^ (MAStringDescription auto: 'lectureName' label: 'Lehrveranstaltung' priority: 10)
			beRequired;
			yourself.
! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 19:30'!
descriptionSemester
	^ (MASingleOptionDescription auto: 'semester' label: 'Semester' priority: 50)
			optionsAndLabels: (DLSemester getKeyValueSelect: [:aSemester | aSemester year > 2008]);
			beRequired;
			reference: MAStringDescription new;
			yourself.! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 20:36'!
descriptionTeacher

	^ (MASingleOptionDescription auto: 'teacher' label: 'Dozent' priority: 10)
		optionsAndLabels: (DLUser getKeyValueSelect: [:aUser | ]);
		yourself.
! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'cr 5/31/2009 16:01'!
descriptionVisible
"	^ MABooleanDescription new
			accessor: #lectureVisibility;
			label: 'visible';
			componentClass: MACheckboxComponent;
			yourself.
"! !

!DLLecture class methodsFor: 'as yet unclassified' stamp: 'Marik 5/27/2009 15:47'!
getOrCreateUserName: aLectureName semester: aSemester description: aDescription

	| lecture |
	lecture := (SqsSearch for: self) detect: [:aLecture | 
		(aLecture lectureName = aLectureName) & (aLecture semester = aSemester)]
	                                 ifNone: [nil].
	lecture ifNotNil: [ ^ lecture ].
	^ self createLectureName: aLectureName semester: aSemester description: aDescription.
! !

!DLLecture class methodsFor: 'persistence-description' stamp: ''!
sqsDescrAssistants
	^ SqsCollectionDescription new manuallyMaintained: false;
		 collectionClass: #OrderedCollection;
		 tableName: 'dl_lectures_assistants';
		 ownerColumn: (SqsColumn basicNew instVarAt: 1 put: nil;
			 instVarAt: 2 put: false;
			 instVarAt: 3 put: 'dl_lecture_id';
			 instVarAt: 4 put: #integer;
			 instVarAt: 5 put: nil;
			 instVarAt: 6 put: nil;
			 instVarAt: 7 put: (SqsForeignKeyDescription new manuallyMaintained: false;
				 referencedColumns: (Set new add: 'id';
					 yourself);
				 referencedTable: 'dl_lectures';
				 updateActions: #();
				 deleteActions: (OrderedCollection new add: #CASCADE;
					 yourself);
				 referencingColumns: (Set new add: 'dl_lecture_id';
					 yourself);
				 yourself);
			 instVarAt: 8 put: false;
			 instVarAt: 9 put: false;
			 instVarAt: 10 put: false;
			 instVarAt: 11 put: #SQSOWNER;
			 yourself);
		 referenceColumn: (SqsColumn basicNew instVarAt: 1 put: nil;
			 instVarAt: 2 put: false;
			 instVarAt: 3 put: 'assistants_id';
			 instVarAt: 4 put: #integer;
			 instVarAt: 5 put: nil;
			 instVarAt: 6 put: nil;
			 instVarAt: 7 put: (SqsForeignKeyDescription new manuallyMaintained: false;
				 referencedColumns: (Set new add: 'id';
					 yourself);
				 referencedTable: 'dl_users';
				 updateActions: #();
				 deleteActions: #(#CASCADE );
				 referencingColumns: (Set new add: 'assistants_id';
					 yourself);
				 yourself);
			 instVarAt: 8 put: false;
			 instVarAt: 9 put: false;
			 instVarAt: 10 put: false;
			 instVarAt: 11 put: #SQSREF;
			 yourself);
		 maintainOrder: true;
		 simpleValues: false;
		 indexType: #integer;
		 referencedClass: #DLUser;
		 linkedVariable: 'assistants';
		 orderField: 'sqs_order_number';
		 yourself! !

!DLLecture class methodsFor: 'persistence-description' stamp: ''!
sqsDescrGroupSize
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'group_size';
		 sqlType: #integer;
		 objectClass: #SmallInteger;
		 tableName: 'dl_lectures';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'groupSize';
		 yourself! !

!DLLecture class methodsFor: 'persistence-description' stamp: ''!
sqsDescrLectureDescription
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'lecture_description';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_lectures';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'lectureDescription';
		 yourself! !

!DLLecture class methodsFor: 'persistence-description' stamp: ''!
sqsDescrLectureName
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'lecture_name';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_lectures';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'lectureName';
		 yourself! !

!DLLecture class methodsFor: 'persistence-description' stamp: ''!
sqsDescrSemester
	^ SqsColumn new associatedClass: #DLSemester;
		 manuallyMaintained: false;
		 columnName: 'semester_id';
		 sqlType: #integer;
		 objectClass: #DLSemester;
		 tableName: 'dl_lectures';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'semester';
		 yourself! !

!DLLecture class methodsFor: 'persistence-description' stamp: ''!
sqsDescrTeacher
	^ SqsColumn new associatedClass: #DLUser;
		 manuallyMaintained: false;
		 columnName: 'teacher_id';
		 sqlType: #integer;
		 objectClass: #DLUser;
		 tableName: 'dl_lectures';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'teacher';
		 yourself! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 6/3/2009 18:08'!
assistants

	^ assistants! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 6/3/2009 18:08'!
assistants: anObject

	assistants := anObject.! !

!DLLecture methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 19:13'!
canonicalName
	^ self lectureName, ' ', self semester canonicalName! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 6/3/2009 20:54'!
descriptionList
 ^ super description select: [:each | #(lectureName lectureDescription teacher assistants semester) includes: each accessor selector]! !

!DLLecture methodsFor: 'accessing' stamp: 'cr 5/31/2009 16:02'!
groupSize

	^ groupSize! !

!DLLecture methodsFor: 'accessing' stamp: 'cr 5/31/2009 16:02'!
groupSize: anObject

	groupSize := anObject.! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 6/3/2009 18:10'!
initialize
	super initialize.
	self assistants: OrderedCollection new.! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/27/2009 16:23'!
lectureDescription

	^ lectureDescription! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/27/2009 16:23'!
lectureDescription: anObject

	lectureDescription := anObject.! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/20/2009 16:23'!
lectureName

	^ lectureName! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/20/2009 16:23'!
lectureName: anObject

	lectureName := anObject.! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/20/2009 16:23'!
semester

	^ semester! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 5/20/2009 16:23'!
semester: anObject

	semester := anObject.! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 6/3/2009 18:08'!
teacher

	^ teacher! !

!DLLecture methodsFor: 'accessing' stamp: 'sebh 6/3/2009 18:08'!
teacher: anObject

	teacher := anObject.! !

!DLModel class methodsFor: 'as yet unclassified' stamp: 'sebh 5/28/2009 14:46'!
createFrom: anArray
	"Create an object with the values given in anArray and use the standard getters/setters so nondefault get/set behaviour works"
	| newobject |
	newobject := self new.
	anArray do: [:element | newobject perform: (element key, ':') asSymbol withArguments: (Array with: element value) ].
	newobject save.
	^ newobject
	! !

!DLModel class methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 19:11'!
getKeyValueSelect: aBlock
	| objects kv |
	objects := (SqsSearch for: self) select: aBlock.
	kv := OrderedCollection new.
	objects do: [:object | kv add: (object -> object canonicalName)].
	^ kv
! !

!DLModel class methodsFor: 'as yet unclassified' stamp: 'sebh 5/28/2009 14:44'!
getOrCreateFrom: anAttributeArray
	"Get an object from a given attribute array, create one if it doesn't exist yet.'"
	| objects keys values |
	keys := anAttributeArray collect: [:anAttribute | anAttribute key].
	values := anAttributeArray collect: [:anAttribute | anAttribute value].
	objects := (SqsSearch for: self) searchBy: keys withValues: values limit:2.
	
	objects size > 1
	ifTrue: [ ^ nil "TODO: Replace this with an exception stating that there is more than one object"].
	objects size = 1
	ifTrue: [ ^ objects at: 1 ]
	ifFalse:[ ^ self createFrom: anAttributeArray ].! !

!DLModel class methodsFor: 'as yet unclassified' stamp: 'sebh 5/28/2009 10:24'!
sqsAbstractBaseClass! !

!DLModel methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 19:09'!
canonicalName
	self subclassResponsibility! !

!DLModel methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 19:44'!
descriptionList
	^ self description! !

!DLModel methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 20:53'!
printString
	^ self canonicalName! !

DLModel subclass: #DLSemester
	instanceVariableNames: 'semesterName year'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLSemester class methodsFor: 'persistence-description' stamp: ''!
sqsDescrSemesterName
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'semester_name';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_semesters';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'semesterName';
		 yourself! !

!DLSemester class methodsFor: 'persistence-description' stamp: ''!
sqsDescrYear
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'year';
		 sqlType: #integer;
		 objectClass: #SmallInteger;
		 tableName: 'dl_semesters';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'year';
		 yourself! !

!DLSemester methodsFor: 'accessing' stamp: 'sebh 6/3/2009 19:13'!
canonicalName
	^ self semesterName, ' ', self year asString.! !

!DLSemester methodsFor: 'accessing' stamp: 'sebh 5/20/2009 15:46'!
semesterName

	^ semesterName! !

!DLSemester methodsFor: 'accessing' stamp: 'sebh 5/20/2009 15:46'!
semesterName: anObject

	semesterName := anObject.! !

!DLSemester methodsFor: 'accessing' stamp: 'sebh 5/20/2009 15:46'!
year

	^ year! !

!DLSemester methodsFor: 'accessing' stamp: 'sebh 5/20/2009 15:46'!
year: anObject

	year := anObject.! !

DLModel subclass: #DLUser
	instanceVariableNames: 'userName email isAdmin'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLUser class methodsFor: 'as yet unclassified' stamp: 'sebh 5/27/2009 13:30'!
createUserName: aUserName email: aEmail
	^ self new
		userName: aUserName;
		email: aEmail;
		save;
		yourself.! !

!DLUser class methodsFor: 'persistence-description' stamp: 'sebh 6/3/2009 18:28'!
descriptionUserName
		^ (MAStringDescription auto: 'userName' label: 'Benutzername' priority: 10)
			beRequired;
			yourself.
! !

!DLUser class methodsFor: 'as yet unclassified' stamp: 'sebh 5/27/2009 13:56'!
getOrCreateUserName: aUserName email: aEmail
	| user |
	user := (SqsSearch for: self) detect: [:aUser | (aUser userName = aUserName)] ifNone: [nil].
	user ifNotNil: [ ^ user ].
	^ self createUserName: aUserName email: aEmail.
! !

!DLUser class methodsFor: 'persistence-description' stamp: 'Marik 5/27/2009 10:23'!
sqsDescrEmail
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'email';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_users';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'email';
		 yourself! !

!DLUser class methodsFor: 'persistence-description' stamp: ''!
sqsDescrIsAdmin
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'is_admin';
		 sqlType: #boolean;
		 objectClass: #False;
		 tableName: 'dl_users';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'isAdmin';
		 yourself! !

!DLUser class methodsFor: 'persistence-description' stamp: 'Marik 5/27/2009 10:24'!
sqsDescrUserName
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'user_name';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_users';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'userName';
		 yourself! !

!DLUser methodsFor: 'accessing' stamp: 'sebh 6/3/2009 19:13'!
canonicalName
	^ self userName, ' <', self email, '>'! !

!DLUser methodsFor: 'accessing' stamp: 'Marik 5/27/2009 10:17'!
email

	^ email! !

!DLUser methodsFor: 'accessing' stamp: 'Marik 5/27/2009 10:17'!
email: anObject

	email := anObject.! !

!DLUser methodsFor: 'initialize-release' stamp: 'sebh 6/3/2009 19:23'!
initialize
	super initialize.
	self isAdmin: false.! !

!DLUser methodsFor: 'accessing' stamp: 'sebh 6/3/2009 17:34'!
isAdmin
	^ isAdmin! !

!DLUser methodsFor: 'accessing' stamp: 'sebh 5/27/2009 23:08'!
isAdmin: anObject

	isAdmin := anObject.! !

!DLUser methodsFor: 'accessing' stamp: 'Marik 5/26/2009 13:25'!
userName

	^ userName! !

!DLUser methodsFor: 'accessing' stamp: 'Marik 5/26/2009 13:25'!
userName: anObject

	userName := anObject.! !

Object subclass: #Tutorials
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli'!

!Tutorials methodsFor: 'as yet unclassified' stamp: 'cr 6/3/2009 21:34'!
DatabaseFixture

"ession := SqsConnectionManager getInstance sessionForClass: DLUser.
session resetDatabase.

	#(2009. 2010. 2011) do: [:each | 
		DLSemester new
			semesterName: 'Sommer';
			year: each;
			save.
		DLSemester new
			semesterName: 'Winter';
			year: each;
			save.
	].

	semester := (SqsSearch for: DLSemester) detect: 
	[:aSemester |( aSemester semesterName = 'Sommer') & (aSemester year = 2009)].
	
	lecture := DLLecture new
		lectureName: 'Softwaretechnik I';
		lectureDescription: 'An introduction to techniques in software development';
		semester: semester;
		save.
	

	user := DLUser createFrom: {#userName->'christian.ress'. #email->'christian.ress@student.hpi.uni-potsdam.de'. #isAdmin->false}.
	
	userJack := DLUser createFrom: {#userName->'jack'. #email->'jack@hpi.uni-potsdam.de'. #isAdmin->true}.
	userJohn := DLUser createFrom: {#userName->'john'. #email->'john@hpi.uni-potsdam.de'. #isAdmin->false}.
	
	membership := DLLectureMembership new
		user: user;
		lecture: lecture;
		role: #student;
		save.

	group := DLGroup new
		groupName: 'Roundup porns';
		groupDescription: 'Roundup in awesome';
		lecture: lecture;
		users: ( {user} as: OrderedCollection );
		save.

DLLecture basicCategory"! !

!Tutorials methodsFor: 'as yet unclassified' stamp: 'sebh 6/2/2009 13:50'!
HowToResetYourDB

"session := SqsConnectionManager getInstance sessionForClass: DLUser.
session resetDatabase.
"! !

!Tutorials methodsFor: 'as yet unclassified' stamp: 'Marik 5/19/2009 17:41'!
HowToUseHPILogin

"
--> Load LDAPlayer v47 via SqueakMapPackageLoader
--> Load HPILogin class via Monticello from Repository http://www.hpi.uni-potsdam.de/hirschfeld/squeaksource/HPILogin

--> Use

hpi := HPILoginChecker new.
hpi checkLogin: 'surname.name' password: '******'"! !

!Tutorials methodsFor: 'as yet unclassified' stamp: 'sebh 6/3/2009 16:33'!
WhatToInstall
"
Magritte

Announcements
MCHttpRepository
	location: 'http://source.lukas-renggli.ch/announcements'
	user: ''
	password: ''

SqsSave aktualisieren.
"! !

SqsSearchInterface subclass: #DLGroup
	instanceVariableNames: 'groupName groupDescription lecture users'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLGroup class methodsFor: 'persistence-description' stamp: ''!
sqsDescrDescription
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'description';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_groups';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'description';
		 yourself! !

!DLGroup class methodsFor: 'persistence-description' stamp: ''!
sqsDescrGroupDescription
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'group_description';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_groups';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'groupDescription';
		 yourself! !

!DLGroup class methodsFor: 'persistence-description' stamp: ''!
sqsDescrGroupName
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'group_name';
		 sqlType: #string;
		 objectClass: #ByteString;
		 tableName: 'dl_groups';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'groupName';
		 yourself! !

!DLGroup class methodsFor: 'persistence-description' stamp: ''!
sqsDescrLecture
	^ SqsColumn new associatedClass: #DLLecture;
		 manuallyMaintained: false;
		 columnName: 'lecture_id';
		 sqlType: #integer;
		 objectClass: #DLLecture;
		 tableName: 'dl_groups';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'lecture';
		 yourself! !

!DLGroup class methodsFor: 'persistence-description' stamp: ''!
sqsDescrUsers
	^ SqsCollectionDescription new manuallyMaintained: false;
		 collectionClass: #OrderedCollection;
		 tableName: 'dl_groups_users';
		 ownerColumn: (SqsColumn basicNew instVarAt: 1 put: nil;
			 instVarAt: 2 put: false;
			 instVarAt: 3 put: 'dl_group_id';
			 instVarAt: 4 put: #integer;
			 instVarAt: 5 put: nil;
			 instVarAt: 6 put: nil;
			 instVarAt: 7 put: (SqsForeignKeyDescription new manuallyMaintained: false;
				 referencedColumns: (Set new add: 'id';
					 yourself);
				 referencedTable: 'dl_groups';
				 updateActions: #();
				 deleteActions: (OrderedCollection new add: #CASCADE;
					 yourself);
				 referencingColumns: (Set new add: 'dl_group_id';
					 yourself);
				 yourself);
			 instVarAt: 8 put: false;
			 instVarAt: 9 put: false;
			 instVarAt: 10 put: false;
			 instVarAt: 11 put: #SQSOWNER;
			 yourself);
		 referenceColumn: (SqsColumn basicNew instVarAt: 1 put: nil;
			 instVarAt: 2 put: false;
			 instVarAt: 3 put: 'users_id';
			 instVarAt: 4 put: #integer;
			 instVarAt: 5 put: nil;
			 instVarAt: 6 put: nil;
			 instVarAt: 7 put: (SqsForeignKeyDescription new manuallyMaintained: false;
				 referencedColumns: (Set new add: 'id';
					 yourself);
				 referencedTable: 'dl_users';
				 updateActions: #();
				 deleteActions: #(#CASCADE );
				 referencingColumns: (Set new add: 'users_id';
					 yourself);
				 yourself);
			 instVarAt: 8 put: false;
			 instVarAt: 9 put: false;
			 instVarAt: 10 put: false;
			 instVarAt: 11 put: #SQSREF;
			 yourself);
		 maintainOrder: true;
		 simpleValues: false;
		 indexType: #integer;
		 referencedClass: #DLUser;
		 linkedVariable: 'users';
		 orderField: 'sqs_order_number';
		 yourself! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/27/2009 16:27'!
groupDescription

	^ groupDescription! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/27/2009 16:27'!
groupDescription: anObject

	groupDescription := anObject.! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:54'!
groupName

	^ groupName! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/20/2009 20:54'!
groupName: anObject

	groupName := anObject.! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/26/2009 12:00'!
initialize
	super initialize.
	self users: OrderedCollection new.! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/26/2009 11:19'!
lecture

	^ lecture! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/26/2009 11:19'!
lecture: anObject

	lecture := anObject.! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/26/2009 11:19'!
users

	^ users! !

!DLGroup methodsFor: 'accessing' stamp: 'sebh 5/26/2009 11:19'!
users: anObject

	users := anObject.! !

SqsSearchInterface subclass: #DLLectureMembership
	instanceVariableNames: 'lecture user role'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLLectureMembership class methodsFor: 'persistence-description' stamp: ''!
sqsDescrLecture
	^ SqsColumn new associatedClass: #DLLecture;
		 manuallyMaintained: false;
		 columnName: 'lecture_id';
		 sqlType: #integer;
		 objectClass: #DLLecture;
		 tableName: 'dl_lecture_memberships';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'lecture';
		 yourself! !

!DLLectureMembership class methodsFor: 'persistence-description' stamp: ''!
sqsDescrRole
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'role';
		 sqlType: #string;
		 objectClass: #ByteSymbol;
		 tableName: 'dl_lecture_memberships';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'role';
		 yourself! !

!DLLectureMembership class methodsFor: 'persistence-description' stamp: ''!
sqsDescrUser
	^ SqsColumn new associatedClass: #DLUser;
		 manuallyMaintained: false;
		 columnName: 'user_id';
		 sqlType: #integer;
		 objectClass: #DLUser;
		 tableName: 'dl_lecture_memberships';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'user';
		 yourself! !

!DLLectureMembership class methodsFor: 'as yet unclassified' stamp: 'sebh 5/26/2009 09:20'!
withLecture: aLecture user: aUser role: aRole
	
	| memberships |
	memberships := 
	(SqsSearch for: self) detect: [:aMembership | (aMembership lecture = aLecture) & (aMembership user = aUser)] ifNone: [nil].
	
	memberships ifNotNil: [ ^ nil ].
	
	^ self new
		lecture: aLecture;
		user: aUser;
		role: aRole;
		save;
		yourself.! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 18:48'!
lecture

	^ lecture! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 18:48'!
lecture: anObject

	lecture := anObject.! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:05'!
role

	^ role! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:05'!
role: anObject

	role := anObject.! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 18:48'!
user

	^ user! !

!DLLectureMembership methodsFor: 'accessing' stamp: 'sebh 5/20/2009 18:48'!
user: anObject

	user := anObject.! !

SqsSearchInterface subclass: #DLUpdateModel
	instanceVariableNames: 'created updated'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-models'!

!DLUpdateModel class methodsFor: 'persistence-description' stamp: ''!
sqsDescrCreated
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'created';
		 sqlType: #dateAndTime;
		 objectClass: #DateAndTime;
		 tableName: 'dl_update_models';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'created';
		 yourself! !

!DLUpdateModel class methodsFor: 'persistence-description' stamp: ''!
sqsDescrUpdated
	^ SqsColumn new manuallyMaintained: false;
		 columnName: 'updated';
		 sqlType: #dateAndTime;
		 objectClass: #DateAndTime;
		 tableName: 'dl_update_models';
		 canBeNull: true;
		 isPrimaryKey: false;
		 autoIncrement: false;
		 linkedVariable: 'updated';
		 yourself! !

!DLUpdateModel methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:03'!
created

	^ created! !

!DLUpdateModel methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:03'!
created: anObject

	created := anObject.! !

!DLUpdateModel methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:06'!
initialize
	self created: DateAndTime now.! !

!DLUpdateModel methodsFor: 'as yet unclassified' stamp: 'sebh 5/20/2009 19:06'!
save
	self updated: DateAndTime now.
	super save! !

!DLUpdateModel methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:03'!
updated

	^ updated! !

!DLUpdateModel methodsFor: 'accessing' stamp: 'sebh 5/20/2009 19:03'!
updated: anObject

	updated := anObject.! !

WASession subclass: #DLSession
	instanceVariableNames: 'user announcer'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

!DLSession methodsFor: 'accessing' stamp: 'sebh 6/3/2009 12:04'!
announcer
	^ announcer ifNil: [ announcer := Announcer new. ].! !

!DLSession methodsFor: 'computing' stamp: 'Marik 5/20/2009 17:09'!
isLoggedIn

	^self user isNil not! !

!DLSession methodsFor: 'computing' stamp: 'Marik 5/20/2009 17:09'!
login: aUser

	self user: aUser! !

!DLSession methodsFor: 'computing' stamp: 'Marik 5/20/2009 17:09'!
logout

	self user: nil.! !

!DLSession methodsFor: 'accessing' stamp: 'Marik 5/20/2009 17:08'!
user

	^ user! !

!DLSession methodsFor: 'accessing' stamp: 'Marik 5/20/2009 17:08'!
user: anObject

	user := anObject.! !

WARequest subclass: #DLRequest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-frontend'!

SqsConfig subclass: #DeliSqsConfig
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Deli-configuration'!

!DeliSqsConfig class methodsFor: 'as yet unclassified' stamp: 'sebh 5/20/2009 16:13'!
connectionSpecification
	^ SqsMySQLConnectionSpecification 
		user: 'deli'
		password: ''
		database: 'deli'
		port: 3306
		host: 'localhost'! !
